@@ -14,4 +14,8 @@ def clone(api_url):
 @cli.command()
 @click.argument('flag', required=True)
 def submit(flag):
-    run_submit(flag)
\ No newline at end of file
+    run_submit(flag)
+
+@cli.command()
+def instance():
+    run_instance()
\ No newline at end of file
